==> alghwalbi_core-1.0.1.tar.gz: lib/alghwalbi_core.dart <==
library alghwalbi_core;

import 'dart:core';
import 'package:flutter/gestures.dart';
import 'package:flutter/material.dart';
import 'package:flutter/cupertino.dart';
import 'package:cached_network_image/cached_network_image.dart';
import 'package:flutter/foundation.dart';
import 'dart:math';
import 'package:flutter/services.dart';
import 'package:flutter_markdown/flutter_markdown.dart';
import 'package:image_picker/image_picker.dart';
import 'package:lifecycle/lifecycle.dart';
import 'package:markdown_editable_textinput/format_markdown.dart';
import 'package:markdown_editable_textinput/markdown_text_input.dart';
import 'package:html_editor_enhanced_fork/html_editor.dart';
import 'package:flutter_html/flutter_html.dart';
import 'package:rive/rive.dart';
import 'dart:convert';
import 'package:shared_preferences/shared_preferences.dart';
import 'dart:io';
import 'package:auto_animated/auto_animated.dart' as animation;
import 'package:beamer/beamer.dart';
import 'package:http/http.dart' as http;
import 'package:http_parser/http_parser.dart';
import 'package:path/path.dart' as path;
import 'package:intl/intl.dart' as intl;
import 'package:path_provider/path_provider.dart' as path_provider;
part './main.dart';
part './views/components/text_form_label.dart';
part './views/components/text_form_widget.dart';
part './views/components/text_form_feild.dart';
part './views/components/search_box.dart';
part './views/components/network_image.dart';
part './views/components/multi_select_dialog.dart';
part './views/components/multi_select.dart';
part './views/components/form.component.dart';
part './views/components/checkbox.dart';
part './views/components/button_post.dart';
part './views/components/button_icon_text.dart';
part './views/components/select_dialog.dart';
part 'views/base_page/mobile.scaffold.dart';
part 'views/base_page/mobile.header.dart';
part 'views/components/multi_lang_text_field.dart';
part 'views/components/multi_lang_html_editor.dart';
part 'views/components/text.dart';
part 'views/base_page/delegates/transform.delegate.dart';
part 'views/base_page/delegates/fadeOut.delegate.dart';
part 'views/base_page/delegates/fixed.delegate.dart';
part 'views/base_page/delegates/scale.delegate.dart';
part 'views/base_page/delegates/transition.delegate.dart';
part 'views/base_page/delegates/builder.delegate.dart';
part 'views/base_page/delegates/delegate.config.dart';
part './services/api.service.dart';
part './services/config.service.dart';
part './services/image.service.dart';
part './services/layout.service.dart';
part './services/navigation.service.dart';
part './services/theme.service.dart';
part './services/beamer_service.dart';
part './models/base_model.dart';
part './models/property.model.dart';
part './models/property_type.enum.dart';
part './interfaces/theme.interface.dart';
part './helpers/message_type.dart';
part './helpers/operation_result.dart';
part './helpers/extensions.dart';
part './controllers/base_controller.dart';
part 'controllers/core_controller.dart';
part './views/state.dart';
part 'views/core_state.dart';

==> alghwalbi_core-1.0.3.tar.gz: lib/alghwalbi_core.dart <==
library alghwalbi_core;

import 'dart:core';
import 'package:flutter/gestures.dart';
import 'package:flutter/material.dart';
import 'package:flutter/cupertino.dart';
import 'package:cached_network_image/cached_network_image.dart';
import 'package:flutter/foundation.dart';
import 'dart:math';
import 'package:flutter/services.dart';
import 'package:image_picker/image_picker.dart';
import 'package:lifecycle/lifecycle.dart';
import 'package:rive/rive.dart';
import 'dart:convert';
import 'package:shared_preferences/shared_preferences.dart';
import 'dart:io';
import 'package:auto_animated/auto_animated.dart' as animation;
import 'package:beamer/beamer.dart';
import 'package:http/http.dart' as http;
import 'package:http_parser/http_parser.dart';
import 'package:path/path.dart' as path;
import 'package:intl/intl.dart' as intl;
import 'package:path_provider/path_provider.dart' as path_provider;
part './main.dart';
part './views/components/text_form_label.dart';
part './views/components/text_form_widget.dart';
part './views/components/text_form_feild.dart';
part './views/components/search_box.dart';
part './views/components/network_image.dart';
part './views/components/multi_select_dialog.dart';
part './views/components/multi_select.dart';
part './views/components/form.component.dart';
part './views/components/checkbox.dart';
part './views/components/button_post.dart';
part './views/components/button_icon_text.dart';
part './views/components/select_dialog.dart';
part 'views/base_page/mobile.scaffold.dart';
part 'views/base_page/mobile.header.dart';
// part 'views/components/multi_lang_text_field.dart';
// part 'views/components/multi_lang_html_editor.dart';
part 'views/components/text.dart';
part 'views/base_page/delegates/transform.delegate.dart';
part 'views/base_page/delegates/fadeOut.delegate.dart';
part 'views/base_page/delegates/fixed.delegate.dart';
part 'views/base_page/delegates/scale.delegate.dart';
part 'views/base_page/delegates/transition.delegate.dart';
part 'views/base_page/delegates/builder.delegate.dart';
part 'views/base_page/delegates/delegate.config.dart';
part './services/api.service.dart';
part './services/config.service.dart';
part './services/image.service.dart';
part './services/layout.service.dart';
part './services/navigation.service.dart';
part './services/theme.service.dart';
part './services/beamer_service.dart';
part './models/base_model.dart';
part './models/property.model.dart';
part './models/property_type.enum.dart';
part './interfaces/theme.interface.dart';
part './helpers/message_type.dart';
part './helpers/operation_result.dart';
part './helpers/extensions.dart';
part './controllers/base_controller.dart';
part 'controllers/core_controller.dart';
part './views/state.dart';
part 'views/core_state.dart';
